@@ -7,6 +7,12 @@ def main():
     pass
 
 
+@main.command()
+@click.argument('src')
+def crop(src):
+    crop_stage(src)
+
+
 @main.command()
 @click.argument('src')
 def check(src):
