@@ -1,5 +1,3 @@
-import os
-import os.path as osp
 from intentron.utils import *
 from . import *
 
@@ -11,9 +9,7 @@ def pipeline_stage(src, dst):
     :param dst: destination directory
     :return: None
     """
-    src = osp.abspath(src)
-    dst = osp.abspath(dst) if dst else f'{src}-pipeline'
-    print(src, dst)
+    dst = dst if dst else f'{src}-pipeline'
 
     if osp.exists(dst):
         log.info("Resuming the pipeline")
@@ -22,6 +18,7 @@ def pipeline_stage(src, dst):
         touch(dst)
 
     for folder in sorted(os.listdir(src)):
-        load_stage(osp.join(src, folder), osp.join(dst, f'01.{src}-loaded'))
-        parse_stage(osp.join(dst, f'01.{src}-loaded'), osp.join(dst, f'02.{src}-parsed'))
-        fuse_stage(osp.join(dst, f'02.{src}-parsed'), osp.join(dst, f'03.{src}-fused'))
+        load_stage(osp.join(src, folder), osp.join(dst, f'01.{folder}-loaded'))
+        parse_stage(osp.join(dst, f'01.{folder}-loaded'), osp.join(dst, f'02.{folder}-parsed'))
+        fuse_stage(osp.join(dst, f'02.{folder}-parsed'), osp.join(dst, f'03.{folder}-fused'))
+    gather_stage(dst, osp.join(dst, f'04.{osp.basename(dst)}-gathered'))
