@@ -75,7 +75,7 @@ def get_subfolders(folder):
     return output
 
 
-def get_files(folder, ext):
+def get_files(folder, ext=None):
     outputs = []
     if type(ext) is list:
         for root, folder, files in sorted(os.walk(folder)):
@@ -89,7 +89,7 @@ def get_files(folder, ext):
     else:
         for root, folder, files in sorted(os.walk(folder)):
             for file in sorted(files):
-                if ext == 'all':
+                if ext == None:
                     outputs += [osp.join(root, file)]
                 else:
                     if file.endswith(ext):
